@@ -26,9 +26,10 @@ create_course_section <- function(canvas, course_id, section_name, section_start
 
   # Make the API request
   response <- httr::POST(url,
-                         httr::add_headers(Authorization = paste("Bearer", canvas$api_key)),
-                         body = payload,
-                         encode = "json")
+    httr::add_headers(Authorization = paste("Bearer", canvas$api_key)),
+    body = payload,
+    encode = "json"
+  )
 
   # Check the response status code
   if (httr::status_code(response) != 200) {
