@@ -7,6 +7,7 @@
 #'
 #' @return A list of assignments retrieved from the Canvas LMS API.
 #' @export
+#' @importFrom tidyr unnest
 #'
 get_assignments <- function(canvas, course_id) {
   # Construct the API endpoint URL
@@ -15,14 +16,16 @@ get_assignments <- function(canvas, course_id) {
   # Make the API request
   response <- httr::GET(url, httr::add_headers(Authorization = paste("Bearer", canvas$api_key)))
 
-  # Check the response status code
-  if (httr::status_code(response) != 200) {
-    stop("Failed to retrieve assignments. Please check your authentication and API endpoint.")
-  }
+  # Use pagination helper to get all pages
+  responses <- paginate(response, canvas$api_key)
 
-  # Parse the response as JSON
-  assignments <- httr::content(response, "text", encoding = "UTF-8") %>%
-    jsonlite::fromJSON(flatten = TRUE)
+  # Parse and combine all results
+  assignments_list <- lapply(responses, function(resp) {
+    httr::content(resp, "text", encoding = "UTF-8") %>%
+      jsonlite::fromJSON(flatten = TRUE) %>%
+      as.data.frame()
+  })
+  assignments <- dplyr::bind_rows(assignments_list)
 
   # Return the list of assignments
   return(assignments)
